@@ -26,14 +26,13 @@ if TYPE_CHECKING:
         ChatCompletionAudioParam,
     )
 
-    from .types import (
-        LanguageModelMessages,
-        LanguageModelInstructorMode,
-        LanguageModelName,
-        LanguageModelResponse,
-        LanguageModelStream,
-    )
-
+from .types import (
+    LanguageModelMessages,
+    LanguageModelInstructorMode,
+    LanguageModelName,
+    LanguageModelResponse,
+    LanguageModelStream,
+)
 from .model import LanguageModel
 
 
@@ -276,6 +275,8 @@ def run_language_model(
     messages: "LanguageModelMessages",
     instructions: Optional[str] = None,
     mock_response: Optional[bool] = None,
+    verbose: bool = False,
+    debug: bool = False,
     **kwargs: Any,
 ) -> Union["LanguageModelResponse[Any]", "LanguageModelStream[Any]"]:
     """Run a language model request with full parameter support.
@@ -283,6 +284,8 @@ def run_language_model(
     Args:
         messages: The input messages/content for the request
         instructions: Optional system instructions to prepend
+        verbose: If True, set logger to INFO level for detailed output
+        debug: If True, set logger to DEBUG level for maximum verbosity
         **kwargs: All request parameters from LanguageModelRequest
 
     Returns:
@@ -292,11 +295,16 @@ def run_language_model(
     model = kwargs.pop("model", "openai/gpt-4o-mini")
 
     # Create language model instance
-    language_model = LanguageModel(model=model)
+    language_model = LanguageModel(model=model, verbose=verbose, debug=debug)
 
     # Forward to the instance method
     return language_model.run(
-        messages, instructions, mock_response=mock_response, **kwargs
+        messages,
+        instructions,
+        mock_response=mock_response,
+        verbose=verbose,
+        debug=debug,
+        **kwargs,
     )
 
 
@@ -529,6 +537,8 @@ async def async_run_language_model(
     messages: "LanguageModelMessages",
     instructions: Optional[str] = None,
     mock_response: Optional[bool] = None,
+    verbose: bool = False,
+    debug: bool = False,
     **kwargs: Any,
 ) -> Union["LanguageModelResponse[Any]", "LanguageModelStream[Any]"]:
     """Run an async language model request with full parameter support.
@@ -536,6 +546,8 @@ async def async_run_language_model(
     Args:
         messages: The input messages/content for the request
         instructions: Optional system instructions to prepend
+        verbose: If True, set logger to INFO level for detailed output
+        debug: If True, set logger to DEBUG level for maximum verbosity
         **kwargs: All request parameters from LanguageModelRequest
 
     Returns:
@@ -545,9 +557,14 @@ async def async_run_language_model(
     model = kwargs.pop("model", "openai/gpt-4o-mini")
 
     # Create language model instance
-    language_model = LanguageModel(model=model)
+    language_model = LanguageModel(model=model, verbose=verbose, debug=debug)
 
     # Forward to the instance method
     return await language_model.async_run(
-        messages, instructions, mock_response=mock_response, **kwargs
+        messages,
+        instructions,
+        mock_response=mock_response,
+        verbose=verbose,
+        debug=debug,
+        **kwargs,
     )
